# IMRT-QA-Data-Miner
Scans a directory for SNC Patient IMRT QA results.


### Install
~~~~
$ pip install imrt-qa-data-miner
~~~~


### How to run
~~~~
$ imrt-qa-data-miner <initial-scan-dir> <optional-output-filename>
~~~~

### Notes
This script was written specifically for SNC Patient, but I'd be happy to include support for other vendors 
if someone could provide some anonymized example reports.